;; Generated package description from ampc.el  -*- no-byte-compile: t -*-
(define-package "ampc" "0.2.0.20240220.181558" "Asynchronous Music Player Controller" '((emacs "24.3")) :commit "66aa7f4fac620fc07bec3bf36937edd07234ff9f" :url "https://elpa.gnu.org/packages/ampc.html" :authors '(("Christopher Schmidt" . "christopher@ch.ristopher.com")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("ampc" "mpc" "mpd"))
